@@ -918,6 +918,8 @@ public:
       return ExtensionID::SPV_INTEL_function_variants;
     case internal::CapabilityBFloat16ArithmeticINTEL:
       return ExtensionID::SPV_INTEL_bfloat16_arithmetic;
+    case internal::CapabilityDeviceBarrierINTEL:
+      return ExtensionID::SPV_INTEL_device_barrier;
     default:
       return {};
     }
